@@ -1,7 +1,7 @@
 package Log::Any::For::Builtins;
 
-our $DATE = '2014-12-10'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-01-12'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,7 @@ sub import {
 }
 
 1;
-# ABSTRACT: Log builtin functions
+# ABSTRACT: (DEPRECATED) Log builtin functions
 
 __END__
 
@@ -75,11 +75,11 @@ __END__
 
 =head1 NAME
 
-Log::Any::For::Builtins - Log builtin functions
+Log::Any::For::Builtins - (DEPRECATED) Log builtin functions
 
 =head1 VERSION
 
-This document describes version 0.09 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2014-12-10.
+This document describes version 0.10 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2015-01-12.
 
 =head1 SYNOPSIS
 
@@ -98,6 +98,10 @@ When run, it might produce logs like:
 
 =head1 DESCRIPTION
 
+B<DEPRECATED:> This module is now deprecated in favor of L<IPC::System::Options>
+(which can do logging and more). This module will be removed from CPAN once
+there are no reverse dependencies on it.
+
 This module provides replacement for some builtin functions (and operators). The
 replacement behaves exactly the same, except that they are peppered with log
 statements from L<Log::Any>. The log statements are at C<trace> level.
@@ -145,7 +149,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
